@@ -6,7 +6,8 @@
 .First.lib <- function(libname, pkgname) {
   pkg <- Package(pkgname);
   assign(pkgname, pkg, pos=getPosition(pkg));
-  cat(getName(pkg), " v", getVersion(pkg), " (", getDate(pkg), ")",
-      " successfully loaded. See ?", pkgname, " for help.\n", sep="");
+
+  packageStartupMessage(getName(pkg), " v", getVersion(pkg), " (", 
+    getDate(pkg), ") successfully loaded. See ?", pkgname, " for help.");
 }
 
